Package: geneset
Type: Package
Title: Get Gene Sets for Gene Enrichment Analysis
Version: 0.2.8
Authors@R: 
    c(person(given = "Yunze",
             family = "Liu",
             role = c("aut", "cre"),
             email = "jieandze1314@gmail.com",
             comment = c(ORCID = "0000-0002-7414-8556")))
Maintainer: Yunze Liu <jieandze1314@gmail.com>
URL: https://github.com/GangLiLab/geneset
BugReports: https://github.com/GangLiLab/geneset/issues
Description: Gene sets are fundamental for gene enrichment analysis. The package 'geneset' enables querying 
    gene sets from public databases including 'GO' (Gene Ontology Consortium. (2004) <doi:10.1093/nar/gkh036>), 
    'KEGG' (Minoru et al. (2000) <doi:10.1093/nar/28.1.27>), 
    'WikiPathway' (Marvin et al. (2020) <doi:10.1093/nar/gkaa1024>), 
    'MsigDb' (Arthur et al. (2015) <doi:10.1016/j.cels.2015.12.004>), 
    'Reactome' (David et al. (2011) <doi:10.1093/nar/gkq1018>),
    'MeSH' (Ish et al. (2014) <doi:10.4103/0019-5413.139827>), 
    'DisGeNET' (Janet et al. (2017) <doi:10.1093/nar/gkw943>),
    'Disease Ontology' (Lynn et al. (2011) <doi:10.1093/nar/gkr972>), 
    'Network of Cancer Genes' (Dimitra et al. (2019) <doi:10.1186/s13059-018-1612-0>) and 
    'COVID-19' (Maxim et al. (2020) <doi:10.21203/rs.3.rs-28582/v1>).
    Gene sets are stored in the list object which provides data frame of 'geneset' and 'geneset_name'. 
    The 'geneset' has two columns of term ID and gene ID. The 'geneset_name' has two columns of 
    terms ID and term description.
License: GPL-3
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.6)
Imports: dplyr, RCurl, fst, stringr
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-27 09:12:06 UTC; reedliu1
Author: Yunze Liu [aut, cre] (ORCID: <https://orcid.org/0000-0002-7414-8556>)
Repository: CRAN
Date/Publication: 2026-07-27 09:50:09 UTC
