# Generated by roxygen2: do not edit by hand

export(getEnrichrdb)
export(getGO)
export(getHgDisease)
export(getKEGG)
export(getMesh)
export(getMsigdb)
export(getReactome)
export(getWiki)
importFrom(dplyr,"%>%")
importFrom(dplyr,filter)
importFrom(dplyr,pull)
