#' Datasets
#' go_org contains GO species information
#'
#'
#' @name Datasets
#' @aliases go_org
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' kegg_org contains KEGG species information
#'
#'
#' @name Datasets
#' @aliases kegg_org
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' wiki_org contains WikiPathway species information
#'
#'
#' @name Datasets
#' @aliases wiki_org
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' msigdb_org contains Msigdb species information
#'
#'
#' @name Datasets
#' @aliases msigdb_org
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' enrichr_metadata contains Enrichrdb information
#'
#'
#' @name Datasets
#' @aliases enrichr_metadata
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' reactome_org contains Reactome species information
#'
#'
#' @name Datasets
#' @aliases reactome_org
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' mesh_org contains MeSH species information
#'
#'
#' @name Datasets
#' @aliases mesh_org
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' mesh_metadata contains MeSH information
#'
#'
#' @name Datasets
#' @aliases mesh_metadata
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' org2cate contains all organism to category information
#'
#'
#' @name Datasets
#' @aliases org2cate
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' org2cate contains all organism to category information
#'
#'
#' @name Datasets
#' @aliases org2cate
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' ensOrg_name contains organism name of ensembl
#'
#'
#' @name Datasets
#' @aliases ensOrg_name
#' @docType data
#' @keywords datasets
NULL
