% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getMsigdb.R
\name{getMsigdb}
\alias{getMsigdb}
\title{Get MSigDB geneset and geneset_name}
\usage{
getMsigdb(
  org = "human",
  category = c("H", "C1", "C2-CGP", "C2-CP-BIOCARTA", "C2-CP-KEGG", "C2-CP-PID",
    "C2-CP-REACTOME", "C2-CP-WIKIPATHWAYS", "C3-MIR-MIRDB", "C3-MIR-MIR_Legacy",
    "C3-TFT-GTRD", "C3-TFT-TFT_Legacy", "C4-CGN", "C4-CM", "C5-GO-BP", "C5-GO-CC",
    "C5-GO-MF", "C5-HPO", "C6", "C7-IMMUNESIGDB", "C7-VAX", "C8"),
  download.method = NULL,
  data_dir = NULL
)
}
\arguments{
\item{org}{Organism name from `msigdb_org`.}

\item{category}{MSigDB collection/subcollection name. Existing Human
collection names remain supported; native Mouse collection names such
as "MH", "M1", "M2-CP-REACTOME" and "M5-GO-BP" are also supported.}

\item{download.method}{"auto" (as default if NULL), "wininet" (for windows)}

\item{data_dir}{data saving location, default is the package data directory}
}
\value{
A list including geneset.
}
\description{
Geneset is a data.frame of 2 columns with term id and gene id.
The function keeps the original public interface and automatically
distinguishes Human MSigDB collections from native Mouse MSigDB
collections by `category`.
}
\details{
Human MSigDB collections (e.g. H, C1, C2-CP-REACTOME, C5-GO-BP) may contain ortholog-converted
data for species supported by `msigdb_org`.

Native Mouse MSigDB collections (e.g. MH, M1, M2-CP-REACTOME,
M5-GO-BP) are only support Mus musculus.
}
\examples{
\donttest{
# Human native Hallmark
x <- getMsigdb(org = "human", category = "H", data_dir = tempdir())

# Human MSigDB converted to mouse orthologs
x <- getMsigdb(org = "mouse", category = "H", data_dir = tempdir())

# Native Mouse MSigDB
x <- getMsigdb(org = "mouse", category = "MH", data_dir = tempdir())
}
}
